@@ -131,9 +131,11 @@ def DEFAULT_ENSURERS():
                             to_completions_display_value, str),
     'COMPLETIONS_MENU_ROWS': (is_int, int, str),
     'COMPLETION_QUERY_LIMIT': (is_int, int, str),
+    'DIRSTACK_SIZE': (is_int, int, str),
     'DYNAMIC_CWD_WIDTH': (is_dynamic_cwd_width, to_dynamic_cwd_tuple,
                           dynamic_cwd_tuple_to_str),
     'DYNAMIC_CWD_ELISION_CHAR': (is_string, ensure_string, ensure_string),
+    'EXPAND_ENV_VARS': (is_bool, to_bool, bool_to_str),
     'FORCE_POSIX_PATHS': (is_bool, to_bool, bool_to_str),
     'FOREIGN_ALIASES_OVERRIDE': (is_bool, to_bool, bool_to_str),
     'FUZZY_PATH_COMPLETION': (is_bool, to_bool, bool_to_str),
@@ -158,10 +160,15 @@ def DEFAULT_ENSURERS():
                 seq_to_upper_pathsep),
     'PRETTY_PRINT_RESULTS': (is_bool, to_bool, bool_to_str),
     'PROMPT': (is_string_or_callable, ensure_string, ensure_string),
+    'PUSHD_MINUS': (is_bool, to_bool, bool_to_str),
+    'PUSHD_SILENT': (is_bool, to_bool, bool_to_str),
     'RAISE_SUBPROC_ERROR': (is_bool, to_bool, bool_to_str),
     'RIGHT_PROMPT': (is_string_or_callable, ensure_string, ensure_string),
     'BOTTOM_TOOLBAR': (is_string_or_callable, ensure_string, ensure_string),
     'SUBSEQUENCE_PATH_COMPLETION': (is_bool, to_bool, bool_to_str),
+    'SUGGEST_COMMANDS': (is_bool, to_bool, bool_to_str),
+    'SUGGEST_MAX_NUM': (is_int, int, str),
+    'SUGGEST_THRESHOLD': (is_int, int, str),
     'SUPPRESS_BRANCH_TIMEOUT_MESSAGE': (is_bool, to_bool, bool_to_str),
     'UPDATE_COMPLETIONS_ON_KEYPRESS': (is_bool, to_bool, bool_to_str),
     'UPDATE_OS_ENVIRON': (is_bool, to_bool, bool_to_str),
